@@ -2,15 +2,18 @@ import os
 import shutil
 
 import pytest
-from utils import FIXTURES_DIR, TOX4
+from utils import FIXTURES_DIR, TOX_VERSION, TOX4, modify_config, drop_unsupported_pythons
 
 
 @pytest.fixture(autouse=True)
 def projdir(tmp_path, monkeypatch, worker_id):
     pwd = tmp_path / "projdir"
     pwd.mkdir()
-    for fname in "tox.ini", "setup.py":
+    for fname in "tox.ini", "setup.py", "pyproject.toml":
         shutil.copy(FIXTURES_DIR / fname, pwd)
+    if TOX4:
+        with modify_config(pwd / "tox.ini") as config:
+            config["tox"]["envlist"] = drop_unsupported_pythons(config["tox"]["envlist"])
     monkeypatch.chdir(pwd)
     # https://github.com/pypa/pip/issues/5345#issuecomment-386424455
     monkeypatch.setenv("XDG_CACHE_HOME",
@@ -38,3 +41,16 @@ def print_deps_stdout_arg(request):
 def print_extras_stdout_arg(request):
     """Argument for printing extras to stdout"""
     return request.param
+
+
+@pytest.fixture
+def dependency_groups_support():
+    """Support for dependency groups"""
+    if (TOX_VERSION.major, TOX_VERSION.minor) < (4, 22):
+        raise pytest.skip(reason="requires tox 4.22 or higher")
+
+
+@pytest.fixture(params=("--print-dependency-groups-to-file=-", "--print-dependency-groups-to=-"))
+def print_dependency_groups_stdout_arg(request, dependency_groups_support):
+    """Argument for printing dependency groups to stdout"""
+    return request.param
